@@ -284,7 +284,7 @@ typedef enum {
 } mm_lock_mode;
 
 /* Global Malloc-Replacement API */
-int     MM_create(size_t size, char *file);
+int     MM_create(size_t size, const char *file);
 void    MM_destroy(void);
 int     MM_lock(mm_lock_mode mode);
 int     MM_unlock(void);
@@ -293,13 +293,13 @@ void   *MM_realloc(void *ptr, size_t size);
 void    MM_free(void *ptr);
 void   *MM_calloc(size_t number, size_t size);
 char   *MM_strdup(const char *str);
-size_t  MM_sizeof(void *ptr);
+size_t  MM_sizeof(const void *ptr);
 size_t  MM_maxsize(void);
 size_t  MM_available(void);
 char   *MM_error(void);
 
 /* Standard Malloc-Style API */
-MM     *mm_create(size_t size, char *file);
+MM     *mm_create(size_t size, const char *file);
 void    mm_destroy(MM *mm);
 int     mm_lock(MM *mm, mm_lock_mode mode);
 int     mm_unlock(MM *mm);
@@ -308,18 +308,18 @@ void   *mm_realloc(MM *mm, void *ptr, size_t size);
 void    mm_free(MM *mm, void *ptr);
 void   *mm_calloc(MM *mm, size_t number, size_t size);
 char   *mm_strdup(MM *mm, const char *str);
-size_t  mm_sizeof(MM *mm, void *ptr);
+size_t  mm_sizeof(MM *mm, const void *ptr);
 size_t  mm_maxsize(void);
 size_t  mm_available(MM *mm);
 char   *mm_error(void);
 void    mm_display_info(MM *mm);
 
 /* Low-Level Shared Memory API */
-void   *mm_core_create(size_t size, char *file);
+void   *mm_core_create(size_t size, const char *file);
 void    mm_core_delete(void *core);
-size_t  mm_core_size(void *core);
-int     mm_core_lock(void *core, mm_lock_mode mode);
-int     mm_core_unlock(void *core);
+size_t  mm_core_size(const void *core);
+int     mm_core_lock(const void *core, mm_lock_mode mode);
+int     mm_core_unlock(const void *core);
 size_t  mm_core_maxsegsize(void);
 size_t  mm_core_align2page(size_t size);
 size_t  mm_core_align2word(size_t size);
