@@ -50,7 +50,7 @@
 /*
  * Create a memory pool
  */
-MM *mm_create(size_t usize, char *file)
+MM *mm_create(size_t usize, const char *file)
 {
     MM *mm = NULL;
     void *core;
@@ -365,7 +365,7 @@ char *mm_strdup(MM *mm, const char *str)
 /*
  * Determine user size of a memory chunk
  */
-size_t mm_sizeof(MM *mm, void *ptr)
+size_t mm_sizeof(MM *mm, const void *ptr)
 {
     mem_chunk *mc;
 
