@@ -49,7 +49,7 @@
 
 static MM *mm_global = NULL;
 
-int MM_create(size_t size, char *file)
+int MM_create(size_t size, const char *file)
 {
     if (mm_global != NULL)
         return FALSE;
@@ -117,7 +117,7 @@ char *MM_strdup(const char *str)
     return mm_strdup(mm_global, str);
 }
 
-size_t MM_sizeof(void *ptr)
+size_t MM_sizeof(const void *ptr)
 {
     if (mm_global == NULL)
         return -1;
